@@ -75,7 +75,8 @@ class AMQPData(GeneralData):
                     arguments={'x-message-ttl' : self.ttl})
                 self.channel.queue_bind(self.queue_name, self.exchange, self.routing_key)
             else:
-                self.queue_name = self.channel.queue_declare("",exclusive=True)[0]
+                self.queue_name = self.channel.queue_declare("",exclusive=True)
+                rprint("Queue name from SOURCE", self.queue_name)
                 self.channel.queue_bind(self.queue_name, exchange=self.exchange)
         except Exception as e:
             self.logger.exception("Error declaring queue -> %s" % e)
